@@ -40,6 +40,7 @@ GpsPos::GpsPos(QObject *parent) :
 GpsPos::GpsPos(QObject *parent, QString logmethod) :
     QObject(parent)
 {
+    Q_UNUSED(logmethod);
     writegpxdata();
 }
 
@@ -86,8 +87,6 @@ GpsPos::GpsPos(QObject *parent, int runs, int limit, bool lastkv, bool showsat,
         timer = new QTimer(this);
         connect(timer, SIGNAL(timeout()), this, SLOT(timeout()));
         timer->start(timeout_value);
-        //qtimer
-        //connect sgtimout
     }
 
     if (!script)
@@ -165,7 +164,6 @@ void GpsPos::positionUpdated(const QGeoPositionInfo &info)
         {
             timer->stop();
             timer->start();
-            //qtimer start stop
         }
         #if defined(Q_OS_SAILFISH)
         if (g_run==-1 && log_method=="onlysat")
@@ -207,7 +205,6 @@ void GpsPos::positionUpdated(const QGeoPositionInfo &info)
                 //qDebug() << "Position updated: " << info << " run: "<< g_run;
                 if (b_date || b_time)
                 {
-
                     if (b_date) cout << "Date: " << s_date << "; ";
                     if (b_time) cout << "Time: " << s_time;
                     cout << endl;
@@ -297,6 +294,7 @@ void GpsPos::writelogfile(QString line)
 void GpsPos::writegpxdata()
 {
     QTextStream cout(stdout);
+    int tracknr=1;
 
     QDir userdir=QDir::homePath();
     QFile file(userdir.absolutePath()+"/gpscon.gpx");
@@ -322,18 +320,33 @@ void GpsPos::writegpxdata()
     xmlWriter.writeAttribute("version","1.1");
     xmlWriter.writeAttribute("creator","gpscon");
     xmlWriter.writeStartElement("trk");
+    xmlWriter.writeStartElement("name");
+    xmlWriter.writeCharacters("Track" + QString::number(tracknr));
+    xmlWriter.writeEndElement();
+    xmlWriter.writeStartElement("trkseg");
     QTextStream in(&logfile);
 
     while(!in.atEnd())
     {
         tloglines++;
         QString line = in.readLine();
-        if (line=="newtrack")
+        if (line=="newtrack" || line=="newseg")
         {
-            if (tloglines > 1)
+            if (tloglines > 1 && line=="newtrack")
             {
+                tracknr++;
+                xmlWriter.writeEndElement();
                 xmlWriter.writeEndElement();
                 xmlWriter.writeStartElement("trk");
+                xmlWriter.writeStartElement("name");
+                xmlWriter.writeCharacters("Track" + QString::number(tracknr));
+                xmlWriter.writeEndElement();
+                xmlWriter.writeStartElement("trkseg");
+            }
+            else if (tloglines > 1 && line=="newseg")
+            {
+                xmlWriter.writeEndElement();
+                xmlWriter.writeStartElement("trkseg");
             }
         }
         else
@@ -373,14 +386,15 @@ void GpsPos::writegpxdata()
             }
         }
     }
-    xmlWriter.writeEndElement();
+    xmlWriter.writeEndElement(); //closing segment
+    xmlWriter.writeEndElement(); //closing track
     xmlWriter.writeEndDocument();
     logfile.close();
     file.close();
     //QTextStream cout(stdout);
     cout << "\33[2K\r";
     cout << tgpxlines << "/" << tloglines << endl;
-    qDebug() << "..finished";
+    qDebug() << "..finished, " << tracknr << "Tracks found.";
 }
 
 void GpsPos::timeout()
@@ -402,6 +416,10 @@ void GpsPos::quit(QString input)
     {
         writelogfile("newtrack");
     }
+    else if (input=="s")
+    {
+        writelogfile("newseg");
+    }
 }
 
 void GpsPos::update(QString status)
