@@ -12,6 +12,7 @@
 #include <QGeoSatelliteInfo>
 #endif
 #include <QObject>
+#include <QTimer>
 
 #if !defined(Q_OS_SAILFISH)
 using namespace QtMobility;
@@ -24,12 +25,14 @@ public:
     GpsPos(QObject *parent = 0);
     GpsPos(QObject *parent = 0, QString logmethod="none");
     GpsPos(QObject *parent = 0, bool fout=true, QString posm="all", bool date=false, bool time=false);
-    GpsPos(QObject *parent = 0, int runs=1, int limit=0, bool lastkv=false, bool showsat=false, bool fout=false, QString posm="onlysat", int interval=0, bool date=false, bool time=false, QString logmethod="none", bool newtrack=false, bool script=true);
+    GpsPos(QObject *parent = 0, int runs=1, int limit=0, bool lastkv=false, bool showsat=false, bool fout=false, QString posm="onlysat", int interval=0, bool date=false, bool time=false, QString logmethod="none", bool newtrack=false, bool script=true, int tout=0);
     int g_run;
     int g_runs;
+    QTimer *timer;
     
 signals:
     void finished();
+
     
 public slots:
     void positionUpdated(const QGeoPositionInfo &info);
@@ -38,12 +41,14 @@ public slots:
     void viewSatelliteInfo();
     void quit(QString input);
     void update(QString status);
+    void timeout();
 private:
     void lastknownposition(const QGeoPositionInfo &lastpos);
     void writelogfile(QString line);
     void writegpxdata();
     int full_out;
     int limit_acc;
+    int timeout_value;
     bool b_date;
     bool b_time;
     int m_satellitesInView;
