@@ -37,17 +37,20 @@ MainClass::MainClass(QObject *parent) :
 // will all work as expected.
 void MainClass::run()
 {
+    bool task=true;
     // Add your main code here
     //qDebug() << "MainClass.Run is executing";(
     if (g_interval>g_tout)
     {
         qDebug() << "update intaval > timeout";
+        task=false;
         quit();
     }
     if (g_del) deletelogfiles();
     if (g_log=="log2gpx")
     {
         m_position = new GpsPos(this, g_log);
+        task=false;
         quit();
         //connect(m_position, SIGNAL(finished()),this, SLOT(quit()));
     }
@@ -56,7 +59,7 @@ void MainClass::run()
         m_position = new GpsPos(this, g_fout, g_posm, g_date, g_time);
         quit();
     }
-    else
+    else if (task)
     {
         m_position = new GpsPos(this, g_runs, g_limit, g_lknv, g_sat, g_fout, g_posm, g_interval, g_date, g_time, g_log, g_newtrack, g_script, g_tout);
         connect(m_position, SIGNAL(finished()),this, SLOT(quit()));
